==> ttkDesigner-0.30.0a50-py3-none-any.whl: ttkDesigner/app/superobj/__init__.py <==

# MIT License
#
# Copyright (c) 2023 Eugenio Parodi <ceccopierangiolieugenio AT googlemail DOT com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from .supercontrol import SuperControlWidget

from .superwidget            import SuperWidget
from .superwidgettextedit    import SuperWidgetTextEdit
from .superwidgetradiobutton import SuperWidgetRadioButton

from .superlayout     import SuperLayout
from .superlayoutgrid import SuperLayoutGrid
from .superlayoutvbox import SuperLayoutVBox
from .superlayouthbox import SuperLayoutHBox

==> ttkDesigner-0.37.0a36-py3-none-any.whl: ttkDesigner/app/superobj/__init__.py <==

# MIT License
#
# Copyright (c) 2023 Eugenio Parodi <ceccopierangiolieugenio AT googlemail DOT com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from .supercontrol import SuperControlWidget

from .superwidget            import SuperWidget
from .superwidgetcontainer   import SuperWidgetContainer
from .superwidgetabstractscrollarea import SuperWidgetAbstractScrollArea
# from .superwidgettextedit    import SuperWidgetTextEdit
from .superwidgetradiobutton import SuperWidgetRadioButton
from .superwidgetframe       import SuperWidgetFrame
from .superwidgetsplitter    import SuperWidgetSplitter
# from .superwidgetlist        import SuperWidgetList
from .superwidgetmenubutton  import SuperWidgetMenuButton

from .superlayout     import SuperLayout
from .superlayoutgrid import SuperLayoutGrid
from .superlayoutvbox import SuperLayoutVBox
from .superlayouthbox import SuperLayoutHBox
